/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.tests;

import java.io.File;
import java.util.List;
import static org.thermostat.qa2.framework.Assert.*;
import org.thermostat.qa2.framework.NativeProcess;
import org.thermostat.qa2.framework.ThermostatQAConfig;
import org.thermostat.qa2.framework.annotations.Before;
import org.thermostat.qa2.framework.annotations.SetupStorage;
import org.thermostat.qa2.framework.annotations.RunGnomeKeyring;
import org.thermostat.qa2.framework.annotations.RunStorage;
import org.thermostat.qa2.framework.annotations.Test;
import org.thermostat.qa2.framework.services.ThermostatAgent;
import org.thermostat.qa2.framework.utils.CommonUtilities;
import org.thermostat.qa2.framework.utils.ProcessUtilities;

/**
 * Test class ported from old framework
 *
 * @author Zdeněk Žamberský
 */
public class DBSchemeSmokeTest {

    List<String> scriptOutput;

    @Before
    @SetupStorage(type = "mongo")
    @RunStorage
    @RunGnomeKeyring
    public void setUp() throws Exception {
        ThermostatAgent agent = new ThermostatAgent();
        agent.start();
        assertRuns(agent, "agent should be running");
        CommonUtilities.sleep(5000);
        String script = "." + File.separator + "scripts" + File.separator + "check-collections-smoke.js";
        String[] commands = new String[]{"mongo", "127.0.0.1:" + ThermostatQAConfig.mongoPort, script};
        NativeProcess process = new NativeProcess(ProcessUtilities.getCommandLine(commands));
        process.setStdOutMode(NativeProcess.MODE_LOG_AND_BUFFER);
        process.start();
        process.waitFor();
        scriptOutput = process.getStdoutLines();
    }

    @Test
    public void agentConfig() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for agent-config is OK");
    }

    @Test
    public void backendInfo() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for backend-info is OK");
    }

    @Test
    public void cpuStats() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for cpu-stats is OK");
    }

    @Test
    public void hostInfo() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for host-info is OK");
    }

    @Test
    public void memoryStats() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for memory-stats is OK");
    }

    @Test
    public void numaHostInfo() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for numa-host-info is OK");
    }

    @Test
    public void numaStat() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for numa-stat is OK");
    }

    @Test
    public void vmClassStats() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for vm-class-stats is OK");
    }

    @Test
    public void vmCpuStats() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for vm-cpu-stats is OK");
    }

    @Test
    public void vmGcStats() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for vm-gc-stats is OK");
    }

    @Test
    public void vmInfo() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for vm-info is OK");
    }

    @Test
    public void vmMemoryStats() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for vm-memory-stats is OK");
    }

    @Test
    public void vmThreadHarvesting() {
        assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        assertContainsPattern(scriptOutput, "schema for vm-thread-harvesting is OK");
    }

}
