/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.tests;

import static org.thermostat.qa2.framework.Assert.assertRuns;
import org.thermostat.qa2.framework.Robot;
import org.thermostat.qa2.framework.Shell;
import org.thermostat.qa2.framework.ThermostatQAConfig;
import org.thermostat.qa2.framework.annotations.SetupStorage;
import org.thermostat.qa2.framework.annotations.RunGnomeKeyring;
import org.thermostat.qa2.framework.annotations.RunStorage;
import org.thermostat.qa2.framework.annotations.Test;
import org.thermostat.qa2.framework.services.ThermostatGui;
import org.thermostat.qa2.framework.utils.ProcessUtilities;

/**
 * Test class ported from old framework
 * @author Zdeněk Žamberský
 */
public class GuiClientDBModificationsSmokeTest {

    public static void addAgentAndSeeItInGuiImpl() throws Exception {
        ThermostatQAConfig.Login login = ThermostatQAConfig.getMongoLogin();

        Shell mongo = ProcessUtilities.createMongoShell();
        mongo.start();
        mongo.writeln("use thermostat");
        mongo.writeln("db.auth(\"" + login.getUsername() + "\",\"" + login.getPassword() + "\")");
        mongo.writeln("db[\"agent-config\"].insert({ \"agentId\" : \"artif-added-agent-for-testing\", \"alive\" : true, \"configListenAddress\" : \"127.0.0.1:12345\", \"startTime\" : NumberLong(\"1234567891011\"), \"stopTime\" : NumberLong(0) })");
        mongo.writeln("quit()");
        mongo.waitFor();

        ThermostatGui gui = new ThermostatGui();
        gui.start();
        assertRuns(gui, "thermostat gui should be running");

        Robot robot = new Robot();
        robot.enterMainMenu();
        robot.pressRightKey();
        robot.pressRightKey();
        robot.pressDownKey();
        robot.pressEnterKey();

        robot.makeScreenshot("testAddAgentAndSeeItInGUIWSTest1");

        robot.checkForPattern("AllAgentsDialog/added_agent");
        robot.saveScreenshot("testAddAgentAndSeeItInGUIWSTest2");
    }

    @Test
    @SetupStorage(type = "mongo")
    @RunStorage
    @RunGnomeKeyring
    public void addAgentAndSeeItInGUITest() throws Exception {
        addAgentAndSeeItInGuiImpl();
    }

}
